@@ -1,46 +1,46 @@
 /*******************************************************************
-* reportassistantpages_bugzilla.cpp
-* SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
-* SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
-*
-* SPDX-License-Identifier: GPL-2.0-or-later
-*
-******************************************************************/
+ * reportassistantpages_bugzilla.cpp
+ * SPDX-FileCopyrightText: 2009, 2010, 2011 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+ * SPDX-FileCopyrightText: 2019 Harald Sitter <sitter@kde.org>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
+ ******************************************************************/
 
 #include "reportassistantpages_bugzilla.h"
 
 #include <QAction>
-#include <QTimer>
-#include <QLabel>
 #include <QCheckBox>
-#include <QToolTip>
 #include <QCursor>
+#include <QDesktopServices>
 #include <QFileDialog>
+#include <QLabel>
 #include <QTemporaryFile>
 #include <QTextBrowser>
-#include <QDesktopServices>
+#include <QTimer>
+#include <QToolTip>
 #include <QWindow>
 
 #include "drkonqi_debug.h"
-#include <KMessageBox>
-#include <KLocalizedString>
-#include <kwallet.h>
 #include <KCapacityBar>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <kwallet.h>
 
 /* Unhandled error dialog includes */
-#include <KIO/Job>
 #include <KConfigGroup>
-#include <KSharedConfig>
+#include <KIO/Job>
 #include <KJobWidgets>
+#include <KSharedConfig>
 
-#include "reportinterface.h"
-#include "systeminformation.h"
-#include "crashedapplication.h"
+#include "applicationdetailsexamples.h"
 #include "bugzillalib.h"
-#include "statuswidget.h"
+#include "crashedapplication.h"
 #include "drkonqi.h"
 #include "drkonqi_globals.h"
-#include "applicationdetailsexamples.h"
+#include "reportinterface.h"
+#include "statuswidget.h"
+#include "systeminformation.h"
 
 static const char kWalletEntryName[] = "drkonqi_bugzilla";
 static const char kWalletEntryUsername[] = "username";
@@ -50,26 +50,28 @@ static QString konquerorKWalletEntryName = KDE_BUGZILLA_URL + QStringLiteral("in
 static const char konquerorKWalletEntryUsername[] = "Bugzilla_login";
 static const char konquerorKWalletEntryPassword[] = "Bugzilla_password";
 
-//BEGIN BugzillaLoginPage
+// BEGIN BugzillaLoginPage
 
-BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
-        ReportAssistantPage(parent),
-        m_wallet(nullptr),
-        m_walletWasOpenedBefore(false)
+BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog *parent)
+    : ReportAssistantPage(parent)
+    , m_wallet(nullptr)
+    , m_walletWasOpenedBefore(false)
 {
     connect(bugzillaManager(), &BugzillaManager::loginFinished, this, &BugzillaLoginPage::loginFinished);
     connect(bugzillaManager(), &BugzillaManager::loginError, this, &BugzillaLoginPage::loginError);
 
     ui.setupUi(this);
     ui.m_statusWidget->setIdle(i18nc("@info:status '1' is replaced with the short URL of the bugzilla ",
-                                   "You need to login with your %1 account in order to proceed.",
-                                   QLatin1String(KDE_BUGZILLA_SHORT_URL)));
+                                     "You need to login with your %1 account in order to proceed.",
+                                     QLatin1String(KDE_BUGZILLA_SHORT_URL)));
 
-    KGuiItem::assign(ui.m_loginButton, KGuiItem2(i18nc("@action:button", "Login"),
-                                              QIcon::fromTheme(QStringLiteral("network-connect")),
-                                              i18nc("@info:tooltip", "Use this button to login "
-                                              "to the KDE bug tracking system using the provided "
-                                              "e-mail address and password.")));
+    KGuiItem::assign(ui.m_loginButton,
+                     KGuiItem2(i18nc("@action:button", "Login"),
+                               QIcon::fromTheme(QStringLiteral("network-connect")),
+                               i18nc("@info:tooltip",
+                                     "Use this button to login "
+                                     "to the KDE bug tracking system using the provided "
+                                     "e-mail address and password.")));
     ui.m_loginButton->setEnabled(false);
 
     connect(ui.m_loginButton, &QPushButton::clicked, this, &BugzillaLoginPage::loginClicked);
@@ -80,15 +82,15 @@ BugzillaLoginPage::BugzillaLoginPage(ReportAssistantDialog * parent) :
     connect(ui.m_userEdit, &KLineEdit::textChanged, this, &BugzillaLoginPage::updateLoginButtonStatus);
     connect(ui.m_passwordEdit, &KPasswordLineEdit::passwordChanged, this, &BugzillaLoginPage::updateLoginButtonStatus);
 
-    ui.m_noticeLabel->setText(
-                        xi18nc("@info/rich","<note>You need a user account on the "
-                            "<link url='%1'>KDE bug tracking system</link> in order to "
-                            "file a bug report, because we may need to contact you later "
-                            "for requesting further information. If you do not have "
-                            "one, you can freely <link url='%2'>create one here</link>. "
-                            "Please do not use disposable email accounts.</note>",
-                            DrKonqi::crashedApplication()->bugReportAddress(),
-                            KDE_BUGZILLA_CREATE_ACCOUNT_URL));
+    ui.m_noticeLabel->setText(xi18nc("@info/rich",
+                                     "<note>You need a user account on the "
+                                     "<link url='%1'>KDE bug tracking system</link> in order to "
+                                     "file a bug report, because we may need to contact you later "
+                                     "for requesting further information. If you do not have "
+                                     "one, you can freely <link url='%2'>create one here</link>. "
+                                     "Please do not use disposable email accounts.</note>",
+                                     DrKonqi::crashedApplication()->bugReportAddress(),
+                                     KDE_BUGZILLA_CREATE_ACCOUNT_URL));
 
     // Don't advertise saving credentials when we can't save them.
     // https://bugs.kde.org/show_bug.cgi?id=363570
@@ -111,8 +113,10 @@ void BugzillaLoginPage::updateLoginButtonStatus()
 void BugzillaLoginPage::loginError(const QString &error)
 {
     loginFinished(false);
-    ui.m_statusWidget->setIdle(xi18nc("@info:status","Error when trying to login: "
-                                                 "<message>%1</message>", error));
+    ui.m_statusWidget->setIdle(xi18nc("@info:status",
+                                      "Error when trying to login: "
+                                      "<message>%1</message>",
+                                      error));
 }
 
 void BugzillaLoginPage::aboutToShow()
@@ -135,11 +139,12 @@ void BugzillaLoginPage::aboutToShow()
 
         ui.m_noticeLabel->setVisible(false);
 
-        ui.m_statusWidget->setIdle(i18nc("@info:status the user is logged at the bugtracker site "
-                                      "as USERNAME",
-                                      "Logged in at the KDE bug tracking system (%1) as: %2.",
-                                      QLatin1String(KDE_BUGZILLA_SHORT_URL),
-                                      bugzillaManager()->getUsername()));
+        ui.m_statusWidget->setIdle(
+            i18nc("@info:status the user is logged at the bugtracker site "
+                  "as USERNAME",
+                  "Logged in at the KDE bug tracking system (%1) as: %2.",
+                  QLatin1String(KDE_BUGZILLA_SHORT_URL),
+                  bugzillaManager()->getUsername()));
     } else {
         // Try to show wallet dialog once this dialog is shown
         QTimer::singleShot(100, this, &BugzillaLoginPage::walletLogin);
@@ -149,21 +154,19 @@ void BugzillaLoginPage::aboutToShow()
     }
 }
 
-bool BugzillaLoginPage::kWalletEntryExists(const QString& entryName)
+bool BugzillaLoginPage::kWalletEntryExists(const QString &entryName)
 {
-    return !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(),
-                                               KWallet::Wallet::FormDataFolder(),
-                                               entryName);
+    return !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(), KWallet::Wallet::FormDataFolder(), entryName);
 }
 
 void BugzillaLoginPage::openWallet()
 {
-    //Store if the wallet was previously opened so we can know if we should close it later
+    // Store if the wallet was previously opened so we can know if we should close it later
     m_walletWasOpenedBefore = KWallet::Wallet::isOpen(KWallet::Wallet::NetworkWallet());
 
-    //Request open the wallet
+    // Request open the wallet
     WId windowId = 0;
-    const auto *widget = qobject_cast<QWidget*>(this->parent());
+    const auto *widget = qobject_cast<QWidget *>(this->parent());
     QWindow *window = widget->windowHandle();
     if (window) {
         windowId = window->winId();
@@ -175,14 +178,14 @@ void BugzillaLoginPage::openWallet()
 void BugzillaLoginPage::walletLogin()
 {
     if (!m_wallet) {
-        if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {  //Key exists!
+        if (kWalletEntryExists(QLatin1String(kWalletEntryName))) { // Key exists!
             openWallet();
             ui.m_savePasswordCheckBox->setCheckState(Qt::Checked);
-            //Was the wallet opened?
+            // Was the wallet opened?
             if (m_wallet) {
                 m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
 
-                //Use wallet data to try login
+                // Use wallet data to try login
                 QMap<QString, QString> values;
                 m_wallet->readMap(QLatin1String(kWalletEntryName), values);
                 QString username = values.value(QLatin1String(kWalletEntryUsername));
@@ -194,19 +197,19 @@ void BugzillaLoginPage::walletLogin()
                 }
             }
         } else if (kWalletEntryExists(konquerorKWalletEntryName)) {
-            //If the DrKonqi entry is empty, but a Konqueror entry exists, use and copy it.
+            // If the DrKonqi entry is empty, but a Konqueror entry exists, use and copy it.
             openWallet();
             if (m_wallet) {
                 m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
 
-                //Fetch Konqueror data
+                // Fetch Konqueror data
                 QMap<QString, QString> values;
                 m_wallet->readMap(konquerorKWalletEntryName, values);
                 QString username = values.value(QLatin1String(konquerorKWalletEntryUsername));
                 QString password = values.value(QLatin1String(konquerorKWalletEntryPassword));
 
                 if (!username.isEmpty() && !password.isEmpty()) {
-                    //Copy to DrKonqi own entries
+                    // Copy to DrKonqi own entries
                     values.clear();
                     values.insert(QLatin1String(kWalletEntryUsername), username);
                     values.insert(QLatin1String(kWalletEntryPassword), password);
@@ -218,7 +221,6 @@ void BugzillaLoginPage::walletLogin()
                     ui.m_passwordEdit->setPassword(password);
                 }
             }
-
         }
 
         if (canLogin()) {
@@ -236,11 +238,11 @@ void BugzillaLoginPage::loginClicked()
 
     updateWidget(false);
 
-    if (ui.m_savePasswordCheckBox->checkState()==Qt::Checked) { //Wants to save data
+    if (ui.m_savePasswordCheckBox->checkState() == Qt::Checked) { // Wants to save data
         if (!m_wallet) {
             openWallet();
         }
-        //Got wallet open ?
+        // Got wallet open ?
         if (m_wallet) {
             m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
 
@@ -249,12 +251,12 @@ void BugzillaLoginPage::loginClicked()
             values.insert(QLatin1String(kWalletEntryPassword), ui.m_passwordEdit->password());
             m_wallet->writeMap(QLatin1String(kWalletEntryName), values);
         }
-    } else { //User doesn't want to save or wants to remove.
+    } else { // User doesn't want to save or wants to remove.
         if (kWalletEntryExists(QLatin1String(kWalletEntryName))) {
             if (!m_wallet) {
                 openWallet();
             }
-            //Got wallet open ?
+            // Got wallet open ?
             if (m_wallet) {
                 m_wallet->setFolder(KWallet::Wallet::FormDataFolder());
                 m_wallet->removeEntry(QLatin1String(kWalletEntryName));
@@ -267,8 +269,7 @@ void BugzillaLoginPage::loginClicked()
 
 bool BugzillaLoginPage::canLogin() const
 {
-    return (!(ui.m_userEdit->text().isEmpty() ||
-              ui.m_passwordEdit->password().isEmpty()));
+    return (!(ui.m_userEdit->text().isEmpty() || ui.m_passwordEdit->password().isEmpty()));
 }
 
 void BugzillaLoginPage::login()
@@ -309,8 +310,7 @@ void BugzillaLoginPage::loginFinished(bool logged)
 
         emit loggedTurnToNextPage();
     } else {
-        ui.m_statusWidget->setIdle(i18nc("@info:status",
-                                         "<b>Error: Invalid e-mail address or password</b>"));
+        ui.m_statusWidget->setIdle(i18nc("@info:status", "<b>Error: Invalid e-mail address or password</b>"));
         updateWidget(true);
         ui.m_userEdit->setFocus(Qt::OtherFocusReason);
     }
@@ -318,7 +318,7 @@ void BugzillaLoginPage::loginFinished(bool logged)
 
 BugzillaLoginPage::~BugzillaLoginPage()
 {
-    //Close wallet if we close the assistant in this step
+    // Close wallet if we close the assistant in this step
     if (m_wallet) {
         if (m_wallet->isOpen() && !m_walletWasOpenedBefore) {
             m_wallet->lockWallet();
@@ -327,14 +327,14 @@ BugzillaLoginPage::~BugzillaLoginPage()
     }
 }
 
-//END BugzillaLoginPage
+// END BugzillaLoginPage
 
-//BEGIN BugzillaInformationPage
+// BEGIN BugzillaInformationPage
 
-BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
-        : ReportAssistantPage(parent)
-        , m_textsOK(false)
-        , m_requiredCharacters(1)
+BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog *parent)
+    : ReportAssistantPage(parent)
+    , m_textsOK(false)
+    , m_requiredCharacters(1)
 {
     ui.setupUi(this);
 
@@ -350,12 +350,9 @@ BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
     ui.m_compiledSourcesCheckBox->setChecked(DrKonqi::systemInformation()->compiledSources());
 
     ui.m_messageWidget->setVisible(false);
-    auto retryAction = new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")),
-                                   i18nc("@action/button retry button in error widget",
-                                         "Retry"),
-                                   ui.m_messageWidget);
-    connect(retryAction, &QAction::triggered,
-            this, [this]{
+    auto retryAction =
+        new QAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18nc("@action/button retry button in error widget", "Retry"), ui.m_messageWidget);
+    connect(retryAction, &QAction::triggered, this, [this] {
         ui.m_messageWidget->animatedHide();
         loadDistroCombo();
     });
@@ -366,13 +363,13 @@ BugzillaInformationPage::BugzillaInformationPage(ReportAssistantDialog * parent)
 
 void BugzillaInformationPage::aboutToShow()
 {
-    //Calculate the minimum number of characters required for a description
-    //If creating a new report: minimum 40, maximum 80
-    //If attaching to an existent report: minimum 30, maximum 50
+    // Calculate the minimum number of characters required for a description
+    // If creating a new report: minimum 40, maximum 80
+    // If attaching to an existent report: minimum 30, maximum 50
     int multiplier = (reportInterface()->attachToBugNumber() == 0) ? 10 : 5;
     m_requiredCharacters = 20 + (reportInterface()->selectedOptionsRating() * multiplier);
 
-    //Fill the description textedit with some headings:
+    // Fill the description textedit with some headings:
     QString descriptionTemplate;
     if (ui.m_detailsEdit->toPlainText().isEmpty()) {
         if (reportInterface()->userCanProvideActionsAppDesktop()) {
@@ -387,14 +384,14 @@ void BugzillaInformationPage::aboutToShow()
         ui.m_detailsEdit->setText(descriptionTemplate);
     }
 
-    checkTexts(); //May be the options (canDetail) changed and we need to recheck
+    checkTexts(); // May be the options (canDetail) changed and we need to recheck
 }
 
 int BugzillaInformationPage::currentDescriptionCharactersCount()
 {
     QString description = ui.m_detailsEdit->toPlainText();
 
-    //Do not count template messages, and other misc chars
+    // Do not count template messages, and other misc chars
     description.remove(QStringLiteral("What I was doing when the application crashed"));
     description.remove(QStringLiteral("Unusual behavior I noticed"));
     description.remove(QStringLiteral("Custom settings of the application"));
@@ -408,7 +405,7 @@ int BugzillaInformationPage::currentDescriptionCharactersCount()
 
 void BugzillaInformationPage::checkTexts()
 {
-    //If attaching this report to an existing one then the title is not needed
+    // If attaching this report to an existing one then the title is not needed
     bool showTitle = (reportInterface()->attachToBugNumber() == 0);
     ui.m_titleEdit->setVisible(showTitle);
     ui.m_titleLabel->setVisible(showTitle);
@@ -421,18 +418,15 @@ void BugzillaInformationPage::checkTexts()
         ui.m_detailsEdit->setFocus();
     }
 
-    bool ok = !((ui.m_titleEdit->isVisible() && ui.m_titleEdit->text().isEmpty())
-        || ui.m_detailsEdit->toPlainText().isEmpty());
+    bool ok = !((ui.m_titleEdit->isVisible() && ui.m_titleEdit->text().isEmpty()) || ui.m_detailsEdit->toPlainText().isEmpty());
 
     QString message;
     int percent = currentDescriptionCharactersCount() * 100 / m_requiredCharacters;
     if (percent >= 100) {
         percent = 100;
-        message = i18nc("the minimum required length of a text was reached",
-                        "Minimum length reached");
+        message = i18nc("the minimum required length of a text was reached", "Minimum length reached");
     } else {
-        message = i18nc("the minimum required length of a text wasn't reached yet",
-                        "Provide more information");
+        message = i18nc("the minimum required length of a text wasn't reached yet", "Provide more information");
     }
     m_textCompleteBar->setValue(percent);
     m_textCompleteBar->setText(message);
@@ -457,8 +451,7 @@ void BugzillaInformationPage::loadDistroCombo()
             if (!field) {
                 // This is a bit flimsy but only acts as save guard.
                 // Ideally this code path is never hit.
-                throw Bugzilla::RuntimeException(i18nc("@info/status error",
-                                                       "Failed to get platform list"));
+                throw Bugzilla::RuntimeException(i18nc("@info/status error", "Failed to get platform list"));
             }
             setDistros(field);
         } catch (Bugzilla::Exception &e) {
@@ -508,9 +501,7 @@ void BugzillaInformationPage::setDistroComboError(const QString &error)
     // NB: not being able to resolve the platform isn't a blocking issue.
     // You can still file a report, it'll simply default to unspecified.
 
-    ui.m_messageWidget->setText(i18nc("@info error when talking to the bugzilla API",
-                                      "An error occurred when talking to bugs.kde.org: %1",
-                                      error));
+    ui.m_messageWidget->setText(i18nc("@info error when talking to the bugzilla API", "An error occurred when talking to bugs.kde.org: %1", error));
     ui.m_messageWidget->animatedShow();
 
     ui.m_distroChooserCombo->setVisible(true);
@@ -525,25 +516,31 @@ bool BugzillaInformationPage::showNextPage()
         bool detailsShort = currentDescriptionCharactersCount() < m_requiredCharacters;
 
         if (detailsShort) {
-            //The user input is less than we want.... encourage to write more
-            QString message = i18nc("@info","The description about the crash details does not provide "
-                                        "enough information yet.<br /><br />");
+            // The user input is less than we want.... encourage to write more
+            QString message = i18nc("@info",
+                                    "The description about the crash details does not provide "
+                                    "enough information yet.<br /><br />");
 
-            message += QLatin1Char(' ') + i18nc("@info","The amount of required information is proportional to "
-                                        "the quality of the other information like the backtrace "
-                                        "or the reproducibility rate."
-                                        "<br /><br />");
+            message += QLatin1Char(' ')
+                + i18nc("@info",
+                        "The amount of required information is proportional to "
+                        "the quality of the other information like the backtrace "
+                        "or the reproducibility rate."
+                        "<br /><br />");
 
-            if (reportInterface()->userCanProvideActionsAppDesktop()
-                || reportInterface()->userCanProvideUnusualBehavior()
+            if (reportInterface()->userCanProvideActionsAppDesktop() || reportInterface()->userCanProvideUnusualBehavior()
                 || reportInterface()->userCanProvideApplicationConfigDetails()) {
-                message += QLatin1Char(' ') + i18nc("@info","Previously, you told DrKonqi that you could provide some "
-                                        "contextual information. Try writing more details about your situation. "
-                                        "(even little ones could help us.)<br /><br />");
+                message += QLatin1Char(' ')
+                    + i18nc("@info",
+                            "Previously, you told DrKonqi that you could provide some "
+                            "contextual information. Try writing more details about your situation. "
+                            "(even little ones could help us.)<br /><br />");
             }
 
-            message += QLatin1Char(' ') + i18nc("@info","If you cannot provide more information, your report "
-                                    "will probably waste developers' time. Can you tell us more?");
+            message += QLatin1Char(' ')
+                + i18nc("@info",
+                        "If you cannot provide more information, your report "
+                        "will probably waste developers' time. Can you tell us more?");
 
             KGuiItem yesItem = KStandardGuiItem::yes();
             yesItem.setText(i18n("Yes, let me add more information"));
@@ -551,11 +548,8 @@ bool BugzillaInformationPage::showNextPage()
             KGuiItem noItem = KStandardGuiItem::no();
             noItem.setText(i18n("No, I cannot add any other information"));
 
-            if (KMessageBox::warningYesNo(this, message,
-                                           i18nc("@title:window","We need more information"),
-                                           yesItem, noItem)
-                                            == KMessageBox::No) {
-                //Request the assistant to close itself (it will prompt for confirmation anyways)
+            if (KMessageBox::warningYesNo(this, message, i18nc("@title:window", "We need more information"), yesItem, noItem) == KMessageBox::No) {
+                // Request the assistant to close itself (it will prompt for confirmation anyways)
                 assistant()->close();
                 return false;
             }
@@ -574,14 +568,13 @@ bool BugzillaInformationPage::isComplete()
 
 void BugzillaInformationPage::aboutToHide()
 {
-    //Save fields data
+    // Save fields data
     reportInterface()->setTitle(ui.m_titleEdit->text());
     reportInterface()->setDetailText(ui.m_detailsEdit->toPlainText());
 
     if (ui.m_distroChooserCombo->isVisible()) {
-        //Save bugzilla platform (distribution)
-        QString bugzillaPlatform = ui.m_distroChooserCombo->itemData(
-                                        ui.m_distroChooserCombo->currentIndex()).toString();
+        // Save bugzilla platform (distribution)
+        QString bugzillaPlatform = ui.m_distroChooserCombo->itemData(ui.m_distroChooserCombo->currentIndex()).toString();
         KConfigGroup config(KSharedConfig::openConfig(), "BugzillaInformationPage");
         config.writeEntry("BugzillaPlatform", bugzillaPlatform);
         DrKonqi::systemInformation()->setBugzillaPlatform(bugzillaPlatform);
@@ -593,59 +586,57 @@ void BugzillaInformationPage::aboutToHide()
 void BugzillaInformationPage::showTitleExamples()
 {
     QString titleExamples = xi18nc("@info:tooltip examples of good bug report titles",
-          "<strong>Examples of good titles:</strong><nl />\"Plasma crashed after adding the Notes "
-          "widget and writing on it\"<nl />\"Konqueror crashed when accessing the Facebook "
-          "application 'X'\"<nl />\"Kopete suddenly closed after resuming the computer and "
-          "talking to a MSN buddy\"<nl />\"Kate closed while editing a log file and pressing the "
-          "Delete key a couple of times\"");
+                                   "<strong>Examples of good titles:</strong><nl />\"Plasma crashed after adding the Notes "
+                                   "widget and writing on it\"<nl />\"Konqueror crashed when accessing the Facebook "
+                                   "application 'X'\"<nl />\"Kopete suddenly closed after resuming the computer and "
+                                   "talking to a MSN buddy\"<nl />\"Kate closed while editing a log file and pressing the "
+                                   "Delete key a couple of times\"");
     QToolTip::showText(QCursor::pos(), titleExamples);
 }
 
 void BugzillaInformationPage::showDescriptionHelpExamples()
 {
-    QString descriptionHelp = i18nc("@info:tooltip help and examples of good bug descriptions",
-                                  "Describe in as much detail as possible the crash circumstances:");
+    QString descriptionHelp =
+        i18nc("@info:tooltip help and examples of good bug descriptions", "Describe in as much detail as possible the crash circumstances:");
     if (reportInterface()->userCanProvideActionsAppDesktop()) {
-        descriptionHelp += QLatin1String("<br />") +
-                           i18nc("@info:tooltip help and examples of good bug descriptions",
-                                 "- Detail which actions were you taking inside and outside the "
-                                 "application an instant before the crash.");
+        descriptionHelp += QLatin1String("<br />")
+            + i18nc("@info:tooltip help and examples of good bug descriptions",
+                    "- Detail which actions were you taking inside and outside the "
+                    "application an instant before the crash.");
     }
     if (reportInterface()->userCanProvideUnusualBehavior()) {
-        descriptionHelp += QLatin1String("<br />") +
-                           i18nc("@info:tooltip help and examples of good bug descriptions",
-                                 "- Note if you noticed any unusual behavior in the application "
-                                 "or in the whole environment.");
+        descriptionHelp += QLatin1String("<br />")
+            + i18nc("@info:tooltip help and examples of good bug descriptions",
+                    "- Note if you noticed any unusual behavior in the application "
+                    "or in the whole environment.");
     }
     if (reportInterface()->userCanProvideApplicationConfigDetails()) {
-        descriptionHelp += QLatin1String("<br />") +
-                           i18nc("@info:tooltip help and examples of good bug descriptions",
-                                 "- Note any non-default configuration in the application.");
+        descriptionHelp += QLatin1String("<br />")
+            + i18nc("@info:tooltip help and examples of good bug descriptions", "- Note any non-default configuration in the application.");
         if (reportInterface()->appDetailsExamples()->hasExamples()) {
-            descriptionHelp += QLatin1Char(' ') +
-                               i18nc("@info:tooltip examples of configuration details. "
-                                     "the examples are already translated",
-                                     "Examples: %1",
-                                     reportInterface()->appDetailsExamples()->examples());
+            descriptionHelp += QLatin1Char(' ')
+                + i18nc("@info:tooltip examples of configuration details. "
+                        "the examples are already translated",
+                        "Examples: %1",
+                        reportInterface()->appDetailsExamples()->examples());
         }
     }
     QToolTip::showText(QCursor::pos(), descriptionHelp);
 }
 
-//END BugzillaInformationPage
+// END BugzillaInformationPage
 
-//BEGIN BugzillaPreviewPage
+// BEGIN BugzillaPreviewPage
 
-BugzillaPreviewPage::BugzillaPreviewPage(ReportAssistantDialog * parent)
-        : ReportAssistantPage(parent)
+BugzillaPreviewPage::BugzillaPreviewPage(ReportAssistantDialog *parent)
+    : ReportAssistantPage(parent)
 {
     ui.setupUi(this);
 }
 
 void BugzillaPreviewPage::aboutToShow()
 {
-    ui.m_previewEdit->setText(reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Include,
-                                                                        ReportInterface::Backtrace::Complete));
+    ui.m_previewEdit->setText(reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Include, ReportInterface::Backtrace::Complete));
     assistant()->setAboutToSend(true);
 }
 
@@ -654,33 +645,36 @@ void BugzillaPreviewPage::aboutToHide()
     assistant()->setAboutToSend(false);
 }
 
-//END BugzillaPreviewPage
+// END BugzillaPreviewPage
 
-//BEGIN BugzillaSendPage
+// BEGIN BugzillaSendPage
 
-BugzillaSendPage::BugzillaSendPage(ReportAssistantDialog * parent)
-        : ReportAssistantPage(parent),
-        m_contentsDialog(nullptr)
+BugzillaSendPage::BugzillaSendPage(ReportAssistantDialog *parent)
+    : ReportAssistantPage(parent)
+    , m_contentsDialog(nullptr)
 {
     connect(reportInterface(), &ReportInterface::reportSent, this, &BugzillaSendPage::sent);
     connect(reportInterface(), &ReportInterface::sendReportError, this, &BugzillaSendPage::sendError);
 
     ui.setupUi(this);
 
-    KGuiItem::assign(ui.m_retryButton, KGuiItem2(i18nc("@action:button", "Retry..."),
-                                              QIcon::fromTheme(QStringLiteral("view-refresh")),
-                                              i18nc("@info:tooltip", "Use this button to retry "
-                                                  "sending the crash report if it failed before.")));
+    KGuiItem::assign(ui.m_retryButton,
+                     KGuiItem2(i18nc("@action:button", "Retry..."),
+                               QIcon::fromTheme(QStringLiteral("view-refresh")),
+                               i18nc("@info:tooltip",
+                                     "Use this button to retry "
+                                     "sending the crash report if it failed before.")));
 
     KGuiItem::assign(ui.m_showReportContentsButton,
-                    KGuiItem2(i18nc("@action:button", "Sho&w Contents of the Report"),
-                            QIcon::fromTheme(QStringLiteral("document-preview")),
-                            i18nc("@info:tooltip", "Use this button to show the generated "
-                            "report information about this crash.")));
+                     KGuiItem2(i18nc("@action:button", "Sho&w Contents of the Report"),
+                               QIcon::fromTheme(QStringLiteral("document-preview")),
+                               i18nc("@info:tooltip",
+                                     "Use this button to show the generated "
+                                     "report information about this crash.")));
     connect(ui.m_showReportContentsButton, &QPushButton::clicked, this, &BugzillaSendPage::openReportContents);
 
     ui.m_retryButton->setVisible(false);
-    connect(ui.m_retryButton, &QAbstractButton::clicked, this , &BugzillaSendPage::retryClicked);
+    connect(ui.m_retryButton, &QAbstractButton::clicked, this, &BugzillaSendPage::retryClicked);
 
     ui.m_launchPageOnFinish->setVisible(false);
     ui.m_restartAppOnFinish->setVisible(false);
@@ -696,7 +690,7 @@ void BugzillaSendPage::retryClicked()
 
 void BugzillaSendPage::aboutToShow()
 {
-    ui.m_statusWidget->setBusy(i18nc("@info:status","Sending crash report... (please wait)"));
+    ui.m_statusWidget->setBusy(i18nc("@info:status", "Sending crash report... (please wait)"));
 
     // Trigger relogin. If the user took a long time to prepare the login our
     // token might have gone invalid in the meantime. As a cheap way to prevent
@@ -704,24 +698,18 @@ void BugzillaSendPage::aboutToShow()
     // should reliably ensure that the token is current.
     // Disconnect everything first though, this function may get called a bunch
     // of times, so we don't want duplicated submissions.
-    disconnect(bugzillaManager(), &BugzillaManager::loginFinished,
-               reportInterface(), &ReportInterface::sendBugReport);
-    disconnect(bugzillaManager(), &BugzillaManager::loginError,
-               this, nullptr);
-    connect(bugzillaManager(), &BugzillaManager::loginFinished,
-            reportInterface(), &ReportInterface::sendBugReport);
-    connect(bugzillaManager(), &BugzillaManager::loginError,
-            this, &BugzillaSendPage::sendError);
+    disconnect(bugzillaManager(), &BugzillaManager::loginFinished, reportInterface(), &ReportInterface::sendBugReport);
+    disconnect(bugzillaManager(), &BugzillaManager::loginError, this, nullptr);
+    connect(bugzillaManager(), &BugzillaManager::loginFinished, reportInterface(), &ReportInterface::sendBugReport);
+    connect(bugzillaManager(), &BugzillaManager::loginError, this, &BugzillaSendPage::sendError);
     bugzillaManager()->refreshToken();
 }
 
 void BugzillaSendPage::sent(int bug_id)
 {
     // Disconnect login->submit chain again.
-    disconnect(bugzillaManager(), &BugzillaManager::loginFinished,
-               reportInterface(), &ReportInterface::sendBugReport);
-    disconnect(bugzillaManager(), &BugzillaManager::loginError,
-               this, nullptr);
+    disconnect(bugzillaManager(), &BugzillaManager::loginFinished, reportInterface(), &ReportInterface::sendBugReport);
+    disconnect(bugzillaManager(), &BugzillaManager::loginError, this, nullptr);
 
     ui.m_statusWidget->setVisible(false);
     ui.m_retryButton->setEnabled(false);
@@ -734,18 +722,22 @@ void BugzillaSendPage::sent(int bug_id)
     ui.m_restartAppOnFinish->setChecked(false);
 
     reportUrl = bugzillaManager()->urlForBug(bug_id);
-    ui.m_finishedLabel->setText(xi18nc("@info/rich","Crash report sent.<nl/>"
-                                             "URL: <link>%1</link><nl/>"
-                                             "Thank you for being part of KDE. "
-                                             "You can now close this window.", reportUrl));
+    ui.m_finishedLabel->setText(xi18nc("@info/rich",
+                                       "Crash report sent.<nl/>"
+                                       "URL: <link>%1</link><nl/>"
+                                       "Thank you for being part of KDE. "
+                                       "You can now close this window.",
+                                       reportUrl));
 
     emit finished(false);
 }
 
 void BugzillaSendPage::sendError(const QString &errorString)
 {
-    ui.m_statusWidget->setIdle(xi18nc("@info:status","Error sending the crash report:  "
-                                  "<message>%1.</message>", errorString));
+    ui.m_statusWidget->setIdle(xi18nc("@info:status",
+                                      "Error sending the crash report:  "
+                                      "<message>%1.</message>",
+                                      errorString));
 
     ui.m_retryButton->setEnabled(true);
     ui.m_retryButton->setVisible(true);
@@ -763,12 +755,9 @@ void BugzillaSendPage::finishClicked()
 
 void BugzillaSendPage::openReportContents()
 {
-    if (!m_contentsDialog)
-    {
-        QString report = reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Exclude,
-                                                                   ReportInterface::Backtrace::Complete) + QLatin1Char('\n') +
-                            i18nc("@info report to KDE bugtracker address","Report to %1",
-                                  DrKonqi::crashedApplication()->bugReportAddress());
+    if (!m_contentsDialog) {
+        QString report = reportInterface()->generateReportFullText(ReportInterface::DrKonqiStamp::Exclude, ReportInterface::Backtrace::Complete)
+            + QLatin1Char('\n') + i18nc("@info report to KDE bugtracker address", "Report to %1", DrKonqi::crashedApplication()->bugReportAddress());
         m_contentsDialog = new ReportInformationDialog(report);
     }
     m_contentsDialog->show();
@@ -776,4 +765,4 @@ void BugzillaSendPage::openReportContents()
     m_contentsDialog->activateWindow();
 }
 
-//END BugzillaSendPage
+// END BugzillaSendPage
