@@ -17,8 +17,8 @@
 #include <KSharedConfig>
 #include <QCommandLineParser>
 #include <QDebug>
-#include <QTemporaryFile>
 #include <QFile>
+#include <QTemporaryFile>
 
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -32,58 +32,61 @@
 #include <KWindowSystem>
 #endif
 
+#include "backtracegenerator.h"
 #include "config-drkonqi.h"
+#include "debuggermanager.h"
 #include "drkonqi.h"
 #include "drkonqidialog.h"
 #include "statusnotifier.h"
-#include "debuggermanager.h"
-#include "backtracegenerator.h"
 
 static const char version[] = PROJECT_VERSION;
-static const char description[] = I18N_NOOP("The KDE Crash Handler gives the user feedback "
-                                            "if a program has crashed.");
+static const char description[] = I18N_NOOP(
+    "The KDE Crash Handler gives the user feedback "
+    "if a program has crashed.");
 
-namespace {
-    void openDrKonqiDialog () {
-        DrKonqiDialog *w = new DrKonqiDialog();
-        QObject::connect(qApp, &QCoreApplication::aboutToQuit, w, &QObject::deleteLater);
-        QObject::connect(w, &DrKonqiDialog::rejected, qApp, &QApplication::quit);
-        w->show();
-    #ifdef Q_OS_MACOS
-        KWindowSystem::forceActiveWindow(w->winId());
-    #endif
-    }
-
-    void requestDrKonqiDialog(bool restarted, bool interactionAllowed) {
-        StatusNotifier *statusNotifier = new StatusNotifier();
-        statusNotifier->setActivationAllowed(interactionAllowed);
-        if (interactionAllowed) {
-            statusNotifier->show();
-        }
-        if (!restarted) {
-            statusNotifier->notify();
-        }
-        QObject::connect(statusNotifier, &StatusNotifier::expired, qApp, &QApplication::quit);
-        QObject::connect(statusNotifier, &StatusNotifier::activated, &openDrKonqiDialog);
-    }
-
-    bool isShuttingDown() {
-        if (QDBusConnection::sessionBus().isConnected()) {
-            QDBusInterface remoteApp( QStringLiteral("org.kde.ksmserver"),
-                                      QStringLiteral("/KSMServer"),
-                                      QStringLiteral("org.kde.KSMServerInterface" ));
-
-            QDBusReply<bool> reply = remoteApp.call( QStringLiteral("isShuttingDown") );
-            return reply.isValid() ? reply.value() : false;
-        }
-        return false;
-    }
+namespace
+{
+void openDrKonqiDialog()
+{
+    DrKonqiDialog *w = new DrKonqiDialog();
+    QObject::connect(qApp, &QCoreApplication::aboutToQuit, w, &QObject::deleteLater);
+    QObject::connect(w, &DrKonqiDialog::rejected, qApp, &QApplication::quit);
+    w->show();
+#ifdef Q_OS_MACOS
+    KWindowSystem::forceActiveWindow(w->winId());
+#endif
 }
 
-int main(int argc, char* argv[])
+void requestDrKonqiDialog(bool restarted, bool interactionAllowed)
 {
-#ifndef Q_OS_WIN //krazy:exclude=cpp
-// Drop privs.
+    StatusNotifier *statusNotifier = new StatusNotifier();
+    statusNotifier->setActivationAllowed(interactionAllowed);
+    if (interactionAllowed) {
+        statusNotifier->show();
+    }
+    if (!restarted) {
+        statusNotifier->notify();
+    }
+    QObject::connect(statusNotifier, &StatusNotifier::expired, qApp, &QApplication::quit);
+    QObject::connect(statusNotifier, &StatusNotifier::activated, &openDrKonqiDialog);
+}
+
+bool isShuttingDown()
+{
+    if (QDBusConnection::sessionBus().isConnected()) {
+        QDBusInterface remoteApp(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"));
+
+        QDBusReply<bool> reply = remoteApp.call(QStringLiteral("isShuttingDown"));
+        return reply.isValid() ? reply.value() : false;
+    }
+    return false;
+}
+}
+
+int main(int argc, char *argv[])
+{
+#ifndef Q_OS_WIN // krazy:exclude=cpp
+    // Drop privs.
     setgid(getgid());
     if (setuid(getuid()) < 0 && geteuid() != getuid()) {
         exit(255);
@@ -99,56 +102,54 @@ int main(int argc, char* argv[])
     // Session management is not needed, do not even connect in order to survive longer than ksmserver.
     unsetenv("SESSION_MANAGER");
 
-    KAboutData aboutData(QStringLiteral("drkonqi"), i18n("The KDE Crash Handler"),
-                         QString::fromLatin1(version), i18n(description),
+    KAboutData aboutData(QStringLiteral("drkonqi"),
+                         i18n("The KDE Crash Handler"),
+                         QString::fromLatin1(version),
+                         i18n(description),
                          KAboutLicense::GPL,
                          i18n("(C) 2000-2018, The DrKonqi Authors"));
-    aboutData.addAuthor(i18nc("@info:credit","Hans Petter Bieker"), QString(),
-                         QStringLiteral("bieker@kde.org"));
-    aboutData.addAuthor(i18nc("@info:credit","Dario Andres Rodriguez"), QString(),
-                         QStringLiteral("andresbajotierra@gmail.com"));
-    aboutData.addAuthor(i18nc("@info:credit","George Kiagiadakis"), QString(),
-                         QStringLiteral("gkiagia@users.sourceforge.net"));
-    aboutData.addAuthor(i18nc("@info:credit","A. L. Spehr"), QString(),
-                         QStringLiteral("spehr@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Hans Petter Bieker"), QString(), QStringLiteral("bieker@kde.org"));
+    aboutData.addAuthor(i18nc("@info:credit", "Dario Andres Rodriguez"), QString(), QStringLiteral("andresbajotierra@gmail.com"));
+    aboutData.addAuthor(i18nc("@info:credit", "George Kiagiadakis"), QString(), QStringLiteral("gkiagia@users.sourceforge.net"));
+    aboutData.addAuthor(i18nc("@info:credit", "A. L. Spehr"), QString(), QStringLiteral("spehr@kde.org"));
     KAboutData::setApplicationData(aboutData);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("tools-report-bug"), app.windowIcon()));
 
     QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
 
-    const QCommandLineOption signalOption(QStringLiteral("signal"), i18nc("@info:shell","The signal <number> that was caught"), QStringLiteral("number"));
-    const QCommandLineOption appNameOption(QStringLiteral("appname"), i18nc("@info:shell","<Name> of the program"), QStringLiteral("name"));
-    const QCommandLineOption appPathOption(QStringLiteral("apppath"), i18nc("@info:shell","<Path> to the executable"), QStringLiteral("path"));
-    const QCommandLineOption appVersionOption(QStringLiteral("appversion"), i18nc("@info:shell","The <version> of the program"), QStringLiteral("version"));
-    const QCommandLineOption bugAddressOption(QStringLiteral("bugaddress"), i18nc("@info:shell","The bug <address> to use"), QStringLiteral("address"));
-    const QCommandLineOption programNameOption(QStringLiteral("programname"), i18nc("@info:shell","Translated <name> of the program"), QStringLiteral("name"));
-    const QCommandLineOption pidOption(QStringLiteral("pid"), i18nc("@info:shell","The <PID> of the program"), QStringLiteral("pid"));
-    const QCommandLineOption startupIdOption(QStringLiteral("startupid"), i18nc("@info:shell","Startup <ID> of the program"), QStringLiteral("id"));
-    const QCommandLineOption kdeinitOption(QStringLiteral("kdeinit"), i18nc("@info:shell","The program was started by kdeinit"));
-    const QCommandLineOption saferOption(QStringLiteral("safer"), i18nc("@info:shell","Disable arbitrary disk access"));
-    const QCommandLineOption restartedOption(QStringLiteral("restarted"), i18nc("@info:shell","The program has already been restarted"));
-    const QCommandLineOption keepRunningOption(QStringLiteral("keeprunning"), i18nc("@info:shell","Keep the program running and generate "
-                                                    "the backtrace at startup"));
-    const QCommandLineOption threadOption(QStringLiteral("thread"), i18nc("@info:shell","The <thread id> of the failing thread"), QStringLiteral("threadid"));
-    const QCommandLineOption dialogOption(QStringLiteral("dialog"), i18nc("@info:shell","Do not show a notification but launch the debug dialog directly"));
+    const QCommandLineOption signalOption(QStringLiteral("signal"), i18nc("@info:shell", "The signal <number> that was caught"), QStringLiteral("number"));
+    const QCommandLineOption appNameOption(QStringLiteral("appname"), i18nc("@info:shell", "<Name> of the program"), QStringLiteral("name"));
+    const QCommandLineOption appPathOption(QStringLiteral("apppath"), i18nc("@info:shell", "<Path> to the executable"), QStringLiteral("path"));
+    const QCommandLineOption appVersionOption(QStringLiteral("appversion"), i18nc("@info:shell", "The <version> of the program"), QStringLiteral("version"));
+    const QCommandLineOption bugAddressOption(QStringLiteral("bugaddress"), i18nc("@info:shell", "The bug <address> to use"), QStringLiteral("address"));
+    const QCommandLineOption programNameOption(QStringLiteral("programname"), i18nc("@info:shell", "Translated <name> of the program"), QStringLiteral("name"));
+    const QCommandLineOption pidOption(QStringLiteral("pid"), i18nc("@info:shell", "The <PID> of the program"), QStringLiteral("pid"));
+    const QCommandLineOption startupIdOption(QStringLiteral("startupid"), i18nc("@info:shell", "Startup <ID> of the program"), QStringLiteral("id"));
+    const QCommandLineOption kdeinitOption(QStringLiteral("kdeinit"), i18nc("@info:shell", "The program was started by kdeinit"));
+    const QCommandLineOption saferOption(QStringLiteral("safer"), i18nc("@info:shell", "Disable arbitrary disk access"));
+    const QCommandLineOption restartedOption(QStringLiteral("restarted"), i18nc("@info:shell", "The program has already been restarted"));
+    const QCommandLineOption keepRunningOption(QStringLiteral("keeprunning"),
+                                               i18nc("@info:shell",
+                                                     "Keep the program running and generate "
+                                                     "the backtrace at startup"));
+    const QCommandLineOption threadOption(QStringLiteral("thread"), i18nc("@info:shell", "The <thread id> of the failing thread"), QStringLiteral("threadid"));
+    const QCommandLineOption dialogOption(QStringLiteral("dialog"), i18nc("@info:shell", "Do not show a notification but launch the debug dialog directly"));
 
-    parser.addOptions({
-        signalOption,
-        appNameOption,
-        appPathOption,
-        appVersionOption,
-        bugAddressOption,
-        programNameOption,
-        pidOption,
-        startupIdOption,
-        kdeinitOption,
-        saferOption,
-        restartedOption,
-        keepRunningOption,
-        threadOption,
-        dialogOption
-    });
+    parser.addOptions({signalOption,
+                       appNameOption,
+                       appPathOption,
+                       appVersionOption,
+                       bugAddressOption,
+                       programNameOption,
+                       pidOption,
+                       startupIdOption,
+                       kdeinitOption,
+                       saferOption,
+                       restartedOption,
+                       keepRunningOption,
+                       threadOption,
+                       dialogOption});
 
     // Add all unknown options but make sure to print a warning.
     // This enables older DrKonqi's to run by newer KCrash instances with
